define(
//begin v1.x content
({
        nomatchMessage: "كلمات السرية غير مطابقة.",
		badPasswordMessage: "كلمة سرية غير صحيحة."
})
//end v1.x content
);
